@@ -30,6 +30,8 @@ enum class errc {
     deflate_negotiation_failed,
     control_frame_compression,
     inflate_error,
+    unexpected_rsv,
+    invalid_utf8,
 };
 
 struct ErrorCategory : std::error_category {
